require 'fileutils'
require 'json'

module Dotpack
  module Config
    BASE_DIR = Dir.home + '/.dotpack'
    FLAVORS_PATH = BASE_DIR + '/flavors'

    @flavors = {}
    @flavors_cached = false

    def self.flavor(f)
      cache_flavors
      @flavors[f]
    end

    def self.set_flavor(f, value='')
      value = '' if value.nil?
      cache_flavors
      @flavors[f] = value
    end

    def self.remove_flavor(f)
      cache_flavors
      @flavors.delete f
    end

    def self.flavors
      cache_flavors
      @flavors.clone
    end

    def self.save
      save_flavors
    end

    def self.save_flavors
      return unless @flavors_cached
      File.open(FLAVORS_PATH, 'w') do |file|
        file.puts JSON.unparse(@flavors)
      end
    end

    private
    def self.cache_flavors
      return if @flavors_cached

      FileUtils.mkdir_p BASE_DIR
      unless File.exist? FLAVORS_PATH
        File.write FLAVORS_PATH, "{}"
      end
      @flavors = JSON.parse(File.read(FLAVORS_PATH))
      @flavors_cached = true
    end
  end
end
