require 'fileutils'
require 'dotpack/config'

module Dotpack
  REPO_DIR = Config::BASE_DIR + '/repositories'

  class Repo
    attr_reader :path, :name

    @repos = nil

    def self.all
      return @repos unless @repos.nil?
      FileUtils.mkdir_p REPO_DIR
      @repos = Dir[REPO_DIR + '/*'].map{|p| Repo.new(p)}
      @repos
    end

    def self.find_by_name(name)
      repos = all()
      repos.each do |r|
        return r if r.name == name
      end
      nil
    end

    def update
      Dir.chdir @path
      return false unless system "git fetch origin >/dev/null 2>&1"
      commits = `git log HEAD..origin/master --oneline`
      return false if commits == ""
      last = commits.lines.last.split(' ').first
      puts "Updated #{@name} to #{last}"
      system "git pull -f origin master >/dev/null"
      true
    end

    private
    def initialize(path)
      @path = path
      @name = File.basename(path).sub(/(.*)__/, '\1/')
    end
  end
end
